summaryrefslogtreecommitdiff
path: root/include/configs/eb_cpu5282.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/configs/eb_cpu5282.h')
-rw-r--r--include/configs/eb_cpu5282.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/configs/eb_cpu5282.h b/include/configs/eb_cpu5282.h
index 80a820c913b..80de73d15d5 100644
--- a/include/configs/eb_cpu5282.h
+++ b/include/configs/eb_cpu5282.h
@@ -66,13 +66,13 @@
/*-----------------------------------------------------------------------
* Start addresses for the final memory configuration
* (Set up by the startup code)
* Please note that CONFIG_SYS_SDRAM_BASE _must_ start at 0
*/
-#define CONFIG_SYS_SDRAM_BASE0 0x00000000
-#define CONFIG_SYS_SDRAM_SIZE0 16 /* SDRAM size in MB */
+#define CFG_SYS_SDRAM_BASE0 0x00000000
+#define CFG_SYS_SDRAM_SIZE0 16 /* SDRAM size in MB */
-#define CONFIG_SYS_SDRAM_BASE CONFIG_SYS_SDRAM_BASE0
-#define CONFIG_SYS_SDRAM_SIZE CONFIG_SYS_SDRAM_SIZE0
+#define CFG_SYS_SDRAM_BASE CFG_SYS_SDRAM_BASE0
+#define CFG_SYS_SDRAM_SIZE CFG_SYS_SDRAM_SIZE0
/*
* For booting Linux, the board info and command line data
@@ -103,8 +103,8 @@
#define DCACHE_STATUS (CONFIG_SYS_INIT_RAM_ADDR + \
CONFIG_SYS_INIT_RAM_SIZE - 4)
#define CONFIG_SYS_ICACHE_INV (CF_CACR_CINV + CF_CACR_DCM)
-#define CONFIG_SYS_CACHE_ACR0 (CONFIG_SYS_SDRAM_BASE | \
- CF_ADDRMASK(CONFIG_SYS_SDRAM_SIZE) | \
+#define CONFIG_SYS_CACHE_ACR0 (CFG_SYS_SDRAM_BASE | \
+ CF_ADDRMASK(CFG_SYS_SDRAM_SIZE) | \
CF_ACR_EN | CF_ACR_SM_ALL)
#define CONFIG_SYS_CACHE_ICACR (CF_CACR_CENB | CF_CACR_DISD | \
CF_CACR_CEIB | CF_CACR_DBWE | \
@@ -66,13 +66,13 @@
* Start addresses for the final memory configuration
* (Set up by the startup code)
- * Please note that CONFIG_SYS_SDRAM_BASE _must_ start at 0
+ * Please note that CFG_SYS_SDRAM_BASE _must_ start at 0
*/